class Admin::ModuleModalTemplatesController < OrbitMemberController
	include Admin::ModuleModalTemplatesHelper
	layout "member_plugin"
	before_action :set_module_modal_template, only: [:show, :edit , :update, :destroy]
	before_action :set_plugin
	before_action :get_settings,:only => [:new, :edit, :setting]

	before_action :need_access_right
	before_action :allow_admin_only, :only => [:index, :setting]

	def index
		if params[:sort].present?
			@module_modal_templates = ModuleModalTemplate.order_by(sort).page(params[:page]).per(10)
		else
			@module_modal_templates = ModuleModalTemplate.sort_hash.page(params[:page]).per(10)
		end
	end
	def sort
		case params[:sort]
		when "status"
			@sort = [[:is_top, params[:order]],
					[:is_hot, params[:order]],
					[:is_hidden,params[:order]],
					[:id,params[:order]]]
		when "category"
			@sort = {:category_id=>params[:order]}.merge({:id=>params[:order]})
		else
			if params[:sort].present?
				s = params[:sort].to_s
				@sort = {s=>params[:order]}.merge({:id=>params[:order]})
			else
				@sort = {}
			end
		end
		@sort
	end
	def new
		@member = MemberProfile.find_by(:uid=>params[:uid].to_s) rescue nil
		@module_modal_template = ModuleModalTemplate.new
	end

	def create
		module_modal_template = ModuleModalTemplate.create(module_modal_template_params)
		redirect_to params[:referer_url]
	end
	
	def show
	end
	def analysis
	end
	def analysis_report
		role = params[:role_id]
		analysis_field_name_start = params[:analysis_field_name_start]
		analysis_field_name_end = params[:analysis_field_name_end]
		graph_by = params[:graph_by]

		@data = get_chart_data(analysis_field_name_start,analysis_field_name_end,role,params[:graph_by],params[:time_zone])

		render :layout => false
	end
	
	def download_excel
		analysis_field_name_start = params[:analysis_field_name_start]
		analysis_field_name_end = params[:analysis_field_name_end]
		@data = get_data_for_excel(analysis_field_name_start,analysis_field_name_end,params[:time_zone])
		@protocol = (request.referer.blank? ? "http" : URI(request.referer).scheme)
		@host_url = "#{@protocol}://#{request.host_with_port}"
		respond_to do |format|
			format.xlsx {
				response.headers['Content-Disposition'] = 'attachment; filename="module_modal_templates.xlsx"'
			}
		end
	end

	def edit
	end

	def destroy
		@module_modal_template.destroy
		redirect_to admin_module_modal_templates_path(:page => params[:page])
	end

	def update
		@module_modal_template.update_attributes(module_modal_template_params)
		@module_modal_template.save
		redirect_to params[:referer_url]
	end


	def setting
	end

	def frontend_setting
		@member = MemberProfile.find_by(:uid=>params[:uid].to_s) rescue nil
		@intro = ModuleModalTemplateIntro.find_by(:member_profile_id=>@member.id) rescue nil
		@intro = @intro.nil? ? ModuleModalTemplateIntro.new({:member_profile_id=>@member.id}) : @intro
	end

	def update_frontend_setting
		@member = MemberProfile.find(intro_params['member_profile_id']) rescue nil
		@intro = ModuleModalTemplateIntro.find_by(:member_profile_id=>@member.id) rescue nil
		@intro = @intro.nil? ? ModuleModalTemplateIntro.new({:member_profile_id=>@member.id}) : @intro
		@intro.update_attributes(intro_params)
		@intro.save
		redirect_to URI.encode('/admin/members/'+@member.to_param+'/ModuleModalTemplate')
	end

	def toggle_hide
		if params[:ids]
			@projects = ModuleModalTemplate.any_in(_id: params[:ids])

			@projects.each do |project|
			project.is_hidden = params[:disable]
			project.save
			end
		end

		render json: {"success"=>true}
	end

	private 

	def module_modal_template_params
		params.require(:module_modal_template).permit!
	end

	def intro_params
		params.require(:module_modal_template_intro).permit! rescue nil
	end
	
	def get_settings
		parse_again_start
		@module_modal_template_relateds = ModuleModalTemplateRelated.all
		parse_again_end
	end

	def set_plugin
		@plugin = OrbitApp::Plugin::Registration.all.select{|plugin| plugin.app_name.eql? 'ModuleModalTemplate'}.first
	end

	def set_module_modal_template
		path = request.path.split('/')
		if path.last.include? '-'
			uid = path[-1].split("-").last
			uid = uid.split("?").first
		else
			uid = path[-2].split("-").last
			uid = uid.split("?").first
		end
		@module_modal_template = ModuleModalTemplate.find_by(:uid => uid) rescue ModuleModalTemplate.find(params[:id])
	end
end